@@ -698,7 +698,8 @@ rsaga.get.usage = function(lib, module, env=rsaga.env(), show=TRUE)
 #' @export
 rsaga.html.help = function(lib, module=NULL, use.program.folder = TRUE, env=rsaga.env(), ...)
 {
-    if (env$version == "2.1.0") {
+    if (env$version == "2.1.0" | env$version == "2.1.1" | env$version == "2.1.2" |
+        env$version == "2.1.3" | env$version == "2.1.4" | env$version == "2.2.0") {
         # Convert character string module names to integer code, if possible:
         if (!is.null(module)) {
             if (is.character(module)) {
@@ -755,12 +756,12 @@ rsaga.html.help = function(lib, module=NULL, use.program.folder = TRUE, env=rsag
                     "- Module or library does not exist\n")
             return()
         }
-        browseURL( paste("file://",fnm,sep=""), ...)
+        utils::browseURL( paste("file://",fnm,sep=""), ...)
     } else {
         warning("rsaga.html.help only available for SAGA GIS 2.1.0+.\n",
                 "Redirecting you to the SAGA GIS wiki...")
         url = "http://sourceforge.net/apps/trac/saga-gis/wiki"
-        browseURL(url, ...)
+        utils::browseURL(url, ...)
     }
     return()
 }
@@ -830,11 +831,13 @@ rsaga.geoprocessor = function(
     check.module.exists = TRUE, warn = options("warn")$warn,
     argsep = " ", ... )
 {
-    # Issue warning if using SAGA GIS version that has not been tested with RSAGA:
+# Issue warning if using SAGA GIS version that has not been tested with RSAGA:
     if (!is.null(env$version)) {
         if (!is.na(env$version)) {
-            if (!any(c("2.0.4","2.0.5","2.0.6","2.0.7","2.0.8","2.1.0","2.1.1","2.1.2","2.1.3","2.1.4") == env$version))
-                warning("This RSAGA version has been tested with SAGA GIS versions 2.0.4 - 2.1.4.\n",
+            if (!any(c("2.0.4","2.0.5","2.0.6","2.0.7","2.0.8",
+                       "2.1.0","2.1.1","2.1.2","2.1.3","2.1.4",
+                       "2.2.0") == env$version))
+                warning("This RSAGA version has been tested with SAGA GIS versions 2.0.4 - 2.2.0.\n",
                     "You seem to be using SAGA GIS ", env$version, ", which may cause problems due to\n",
                     "changes in names and definitions of SAGA module arguments, etc.", sep = "" )
         }
